package edu.cmu.cmsip.p6;

import java.io.*;

import weka.core.Attribute;
import weka.core.FastVector;
import weka.core.Instances;
import weka.core.converters.ArffSaver;

/**
 * Add the genre (class label) attribute to an arff file
 * 
 * Usage: AddAttribute <file.arff> <genre>
 * @author dawenl
 *
 */
public class AddAttribute
{
    public static void main(String[] args) throws Exception
    {
        if (args.length != 2) {
            System.out.println("\nUsage: java AddAttribute <file.arff> <genre>\n");
            System.exit(1);
        }
        String filename = args[0];
        String genre = args[1];

        // load dataset
        Instances data = new Instances(new BufferedReader(new FileReader(filename)));
        Instances newData = new Instances(data);
        // add new attribute        
        FastVector values = new FastVector();
        values.addElement("jazz");
        values.addElement("pop");
        values.addElement("metal");
        values.addElement("classical");
        Attribute genreAttr = new Attribute("Genre", values);
        newData.insertAttributeAt(genreAttr, newData.numAttributes());

        // add to each instance
        for (int i = 0; i < newData.numInstances(); i++) {
            newData.instance(i).setValue(newData.numAttributes() - 1, genre);
        }
        
        // save back to the original arff file
        ArffSaver saver = new ArffSaver();
        saver.setInstances(newData);
        saver.setFile(new File(filename));
        // **not** necessary in 3.5.4 and later
        //saver.setDestination(new File("./data/test.arff"));   
        saver.writeBatch();
    }
}
