package edu.cmu.cmsip.p6;

import java.io.File;

import weka.core.Attribute;
import weka.core.FastVector;
import weka.core.Instance;
import weka.core.Instances;
import weka.core.converters.ArffSaver;

/**
 * Generates a little ARFF file with different attribute types.
 * 
 * @author FracPete
 * 
 *         Edit by dawenl
 */
public class CreateArffExample
{
    public static void main(String[] args) throws Exception
    {
        FastVector attsAll; // all the attributes
        FastVector attClass; // attributes for class labels (genres)
        Instances data; // all the data
        double[] vals;

        // 1. set up attributes
        attsAll = new FastVector();
        // - numeric
        attsAll.addElement(new Attribute("feature"));
        // - nominal
        attClass = new FastVector();
        attClass.addElement("jazz");
        attClass.addElement("pop");

        attsAll.addElement(new Attribute("genre", attClass));

        // 2. create Instances object, Instances object will contain all the instance objects
        data = new Instances("MyTest", attsAll, 0);

        // 3. fill with data
        // first instance
        vals = new double[data.numAttributes()];
        // - numeric
        vals[0] = Math.PI;
        // - nominal label
        vals[1] = attClass.indexOf("pop");
        // add first instance into the 'Instances'
        data.add(new Instance(1.0, vals));

        // second instance
        vals = new double[data.numAttributes()]; // important: needs NEW array!
        // - numeric
        vals[0] = Math.E;
        // - nominal label
        vals[1] = attClass.indexOf("jazz");
        // add second instance into the 'Instances'
        data.add(new Instance(1.0, vals));

        // 4. save data
        ArffSaver saver = new ArffSaver();
        saver.setInstances(data);
        saver.setFile(new File("PATH TO SAVE"));
        saver.writeBatch();
    }
}